@@ -65,7 +65,7 @@
 #endif
 
 #include "gtksourcecompletioncontext.h"
-#include "gtksourceview-typebuiltins.h"
+#include "gtksourceview-enumtypes.h"
 #include "gtksourcecompletionprovider.h"
 #include "gtksourceview-i18n.h"
 #include "gtksourcecompletion.h"
@@ -78,24 +78,21 @@ struct _GtkSourceCompletionContextPrivate
 	GtkSourceCompletionActivation activation;
 };
 
-/* Properties */
 enum
 {
 	PROP_0,
-
 	PROP_COMPLETION,
 	PROP_ITER,
 	PROP_ACTIVATION
 };
 
-/* Signals */
 enum
 {
 	CANCELLED,
-	NUM_SIGNALS
+	N_SIGNALS
 };
 
-static guint context_signals[NUM_SIGNALS] = {0,};
+static guint context_signals[N_SIGNALS];
 
 G_DEFINE_TYPE_WITH_PRIVATE (GtkSourceCompletionContext, gtk_source_completion_context, G_TYPE_INITIALLY_UNOWNED)
 
@@ -200,8 +197,11 @@ gtk_source_completion_context_get_property (GObject    *object,
 		case PROP_ITER:
 			{
 				GtkTextIter iter;
-				gtk_source_completion_context_get_iter (context, &iter);
-				g_value_set_boxed (value, &iter);
+
+				if (gtk_source_completion_context_get_iter (context, &iter))
+				{
+					g_value_set_boxed (value, &iter);
+				}
 			}
 			break;
 
@@ -249,7 +249,9 @@ gtk_source_completion_context_class_init (GtkSourceCompletionContextClass *klass
 	                                                      "Completion",
 	                                                      "The completion object to which the context belongs",
 	                                                      GTK_SOURCE_TYPE_COMPLETION,
-	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	                                                      G_PARAM_READWRITE |
+							      G_PARAM_CONSTRUCT_ONLY |
+							      G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletionContext:iter:
@@ -262,7 +264,8 @@ gtk_source_completion_context_class_init (GtkSourceCompletionContextClass *klass
 							     "Iterator",
 							     "The GtkTextIter at which the completion was invoked",
 							     GTK_TYPE_TEXT_ITER,
-							     G_PARAM_READWRITE));
+							     G_PARAM_READWRITE |
+							     G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletionContext:activation:
@@ -276,7 +279,9 @@ gtk_source_completion_context_class_init (GtkSourceCompletionContextClass *klass
 	                                                     "The type of activation",
 	                                                     GTK_SOURCE_TYPE_COMPLETION_ACTIVATION,
 	                                                     GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED,
-	                                                     G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	                                                     G_PARAM_READWRITE |
+							     G_PARAM_CONSTRUCT |
+							     G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -288,8 +293,8 @@ gtk_source_completion_context_init (GtkSourceCompletionContext *context)
 /**
  * gtk_source_completion_context_add_proposals:
  * @context: a #GtkSourceCompletionContext.
- * @provider: (type GtkSource.CompletionProvider): a #GtkSourceCompletionProvider.
- * @proposals: (allow-none) (element-type GtkSource.CompletionProposal): The list of proposals to add.
+ * @provider: a #GtkSourceCompletionProvider.
+ * @proposals: (nullable) (element-type GtkSource.CompletionProposal): The list of proposals to add.
  * @finished: Whether the provider is finished adding proposals.
  *
  * Providers can use this function to add proposals to the completion. They
