@@ -140,7 +140,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -159,7 +159,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -178,7 +178,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -195,7 +195,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -212,7 +212,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -232,7 +232,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -251,7 +251,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward2 (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
