@@ -53,7 +53,9 @@ struct _TestWidgetPrivate
 	GtkSourceBuffer *buffer;
 	GtkSourceFile *file;
 	GtkSourceMap *map;
+	GtkCheckButton *show_top_border_window_checkbutton;
 	GtkCheckButton *show_map_checkbutton;
+	GtkCheckButton *draw_spaces_checkbutton;
 	GtkCheckButton *smart_backspace_checkbutton;
 	GtkCheckButton *indent_width_checkbutton;
 	GtkSpinButton *indent_width_spinbutton;
@@ -225,7 +227,7 @@ load_cb (GtkSourceFileLoader *loader,
 	if (error != NULL)
 	{
 		g_warning ("Error while loading the file: %s", error->message);
-		g_error_free (error);
+		g_clear_error (&error);
 		g_clear_object (&self->priv->file);
 		goto end;
 	}
@@ -338,23 +340,6 @@ highlight_current_line_toggled_cb (TestWidget     *self,
 	gtk_source_view_set_highlight_current_line (self->priv->view, enabled);
 }
 
-static void
-draw_spaces_toggled_cb (TestWidget     *self,
-			GtkCheckButton *button)
-{
-	gboolean draw_spaces = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
-
-	if (draw_spaces)
-	{
-		gtk_source_view_set_draw_spaces (self->priv->view,
-						 GTK_SOURCE_DRAW_SPACES_ALL);
-	}
-	else
-	{
-		gtk_source_view_set_draw_spaces (self->priv->view, 0);
-	}
-}
-
 static void
 wrap_lines_toggled_cb (TestWidget     *self,
 		       GtkCheckButton *button)
@@ -837,22 +822,22 @@ bracket_matched_cb (GtkSourceBuffer           *buffer,
 	GEnumClass *eclass;
 	GEnumValue *evalue;
 
-	g_return_if_fail (iter != NULL);
-
 	eclass = G_ENUM_CLASS (g_type_class_ref (GTK_SOURCE_TYPE_BRACKET_MATCH_TYPE));
 	evalue = g_enum_get_value (eclass, state);
 
 	g_print ("Bracket match state: '%s'\n", evalue->value_nick);
 
+	g_type_class_unref (eclass);
+
 	if (state == GTK_SOURCE_BRACKET_MATCH_FOUND)
 	{
+		g_return_if_fail (iter != NULL);
+
 		g_print ("Matched bracket: '%c' at row: %"G_GINT32_FORMAT", col: %"G_GINT32_FORMAT"\n",
 		         gtk_text_iter_get_char (iter),
 		         gtk_text_iter_get_line (iter) + 1,
 		         gtk_text_iter_get_line_offset (iter) + 1);
 	}
-
-	g_type_class_unref (eclass);
 }
 
 static gchar *
@@ -973,7 +958,6 @@ test_widget_class_init (TestWidgetClass *klass)
 	gtk_widget_class_bind_template_callback (widget_class, show_right_margin_toggled_cb);
 	gtk_widget_class_bind_template_callback (widget_class, right_margin_position_value_changed_cb);
 	gtk_widget_class_bind_template_callback (widget_class, highlight_current_line_toggled_cb);
-	gtk_widget_class_bind_template_callback (widget_class, draw_spaces_toggled_cb);
 	gtk_widget_class_bind_template_callback (widget_class, wrap_lines_toggled_cb);
 	gtk_widget_class_bind_template_callback (widget_class, auto_indent_toggled_cb);
 	gtk_widget_class_bind_template_callback (widget_class, indent_spaces_toggled_cb);
@@ -984,7 +968,9 @@ test_widget_class_init (TestWidgetClass *klass)
 
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, view);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, map);
+	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, show_top_border_window_checkbutton);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, show_map_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, draw_spaces_checkbutton);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, smart_backspace_checkbutton);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, indent_width_checkbutton);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, indent_width_spinbutton);
@@ -993,9 +979,24 @@ test_widget_class_init (TestWidgetClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, background_pattern);
 }
 
+static void
+show_top_border_window_toggled_cb (GtkToggleButton *checkbutton,
+				   TestWidget      *self)
+{
+	gint size;
+
+	size = gtk_toggle_button_get_active (checkbutton) ? 20 : 0;
+
+	gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (self->priv->view),
+					      GTK_TEXT_WINDOW_TOP,
+					      size);
+}
+
 static void
 test_widget_init (TestWidget *self)
 {
+	GtkSourceSpaceDrawer *space_drawer;
+
 	self->priv = test_widget_get_instance_private (self);
 
 	gtk_widget_init_template (GTK_WIDGET (self));
@@ -1005,6 +1006,11 @@ test_widget_init (TestWidget *self)
 
 	g_object_ref (self->priv->buffer);
 
+	g_signal_connect (self->priv->show_top_border_window_checkbutton,
+			  "toggled",
+			  G_CALLBACK (show_top_border_window_toggled_cb),
+			  self);
+
 	g_signal_connect_swapped (self->priv->indent_width_checkbutton,
 				  "toggled",
 				  G_CALLBACK (update_indent_width),
@@ -1060,6 +1066,11 @@ test_widget_init (TestWidget *self)
 	                  G_CALLBACK (on_background_pattern_changed),
 	                  self);
 
+	space_drawer = gtk_source_view_get_space_drawer (self->priv->view);
+	g_object_bind_property (self->priv->draw_spaces_checkbutton, "active",
+				space_drawer, "enable-matrix",
+				G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+
 	open_file (self, TOP_SRCDIR "/gtksourceview/gtksourcebuffer.c");
 }
 
